@@ -8,6 +8,7 @@
 #
 import logging
 from dataclasses import dataclass, asdict
+from enum import StrEnum, unique
 
 from http_tools import AbmServiceConnector
 from init_helpers import dict_to_dataclass
@@ -36,11 +37,21 @@ class TicketClosurePayload:
     solution_message: str
 
 
+@unique
+class TicketStatusCode(StrEnum):
+    CREATED = "created"
+    REGISTERED = "registered"
+    IN_PROGRESS = "in_progress"
+    CLOSED = "closed"
+
+
 @dataclass(frozen=True, slots=True)
 class Ticket:
     type: str
     link: str
     number: str
+    executor_id: str
+    status_code: TicketStatusCode
     
     
 class SUTPGatewayConnector:
@@ -61,7 +72,7 @@ class SUTPGatewayConnector:
     async def create_ticket(self, ticket_creation_payload: TicketCreationPayload) -> Ticket:
         answer = await self._connector.post(
             path="/v1/ticket/create",
-            payload=asdict(ticket_creation_payload),
+            payload={"ticket_creation_payload": asdict(ticket_creation_payload)},
             headers={self._SERVER_NAME_HEADER: self.context.server_name},
         )
 
@@ -69,13 +80,15 @@ class SUTPGatewayConnector:
         logger.info(f"Successfully created {ticket = }")
         return ticket
 
-    async def check_ticket_closure(self, link: str) -> bool:
-        return await self._connector.get(
-            path="/v1/ticket/check_closure",
+    async def get_ticket(self, link: str) -> Ticket:
+        answer = await self._connector.get(
+            path="/v1/ticket/get",
             url_query={"link": link},
             headers={self._SERVER_NAME_HEADER: self.context.server_name},
         )
 
+        return dict_to_dataclass(answer, Ticket)
+
     async def close_ticket(self, ticket_closure_payload: TicketClosurePayload) -> bool:
         return await self._connector.patch(
             path="/v1/ticket/close",
